Fundamental Co-Design Principles Theory
==========================================================

It is important to understand the fundamental physical relationships of consigning photonics and electronics systems. Really, we are combining two engineering fields: photonics engineering and electronics engineering. The overlap between the fields, and interconnected relationships, are essential to optimise the system design between them.


Electronic Fundamentals
=============================

.. include:: electronic/fundamentals.rst
.. include:: electronic/passives.rst
.. include:: electronic/digital_metrics.rst
.. include:: electronic/power_time_metrics.rst
.. include:: electronic/physics.rst

Photonic \& RF Fundamentals
=============================

.. include:: photonic/fundamentals.rst
.. include:: photonic/network_analysis.rst
